==> godot-3.2.3-beta1.tar.xz: godot-3.2.3-beta1/AUTHORS.md <==
# Godot Engine authors

Godot Engine is developed by a community of voluntary contributors who
contribute code, bug reports, documentation, artwork, support, etc.

It is impossible to list them all; nevertheless, this file aims at listing
the developers who contributed significant patches to this MIT licensed
source code. "Significant" is arbitrarily decided, but should be fair :)

GitHub usernames are indicated in parentheses, or as sole entry when no other
name is available.

## Project Founders

    Juan Linietsky (reduz)
    Ariel Manzur (punto-)

## Lead Developer

    Juan Linietsky (reduz)

## Project Manager

    Rémi Verschelde (akien-mga)

## Developers

(in alphabetical order, with over 10 commits excluding merges)

    Aaron Franke (aaronfranke)
    Alexander Holland (AlexHolly)
    Alexey Khoroshavin (allkhor)
    Alket Rexhepi (alketii)
    Andrea Catania (AndreaCatania)
    Andreas Haas (Hinsbart)
    Andrii Doroshenko (Xrayez)
    Andy Moss (MillionOstrich)
    Anish Bhobe (KidRigger)
    Anton Yabchinskiy (a12n)
    Anutrix
    Aren Villanueva (kurikaesu)
    Ariel Manzur (punto-)
    Bastiaan Olij (BastiaanOlij)
    Ben Brookshire (sheepandshepherd)
    Benjamin Larsson (Nallebeorn)
    Bernard Liebl (poke1024)
    Błażej Szczygieł (zaps166)
    Bojidar Marinov (bojidar-bg)
    Bruno Lourenço (MadEqua)
    bruvzg
    Cameron Reikes (creikey)
    Camille Mohr-Daurat (pouleyKetchoupp)
    Carl Olsson (not-surt)
    Carter Anderson (cart)
    Chris Bradfield (cbscribe)
    Clay John (clayjohn)
    Dana Olson (adolson)
    Daniel J. Ramirez (djrm)
    Daniel Rakos (aqnuep)
    dankan1890
    David Sichma (DavidSichma)
    Dharkael (lupoDharkael)
    Dmitry Koteroff (Krakean)
    Dominik Jasiński (dreamsComeTrue)
    DualMatrix
    Emmanuel Barroga (codecustard)
    Emmanuel Leblond (touilleMan)
    Eoin O'Neill (Eoin-ONeill-Yokai)
    Eric Lasota (elasota)
    Eric Rybicki (ericrybick)
    Erik Selecký (rxlecky)
    est31
    Fabian Mathews (supagu)
    Fabio Alessandrelli (Faless)
    Ferenc Arn (tagcup)
    Franklin Sobrinho (TheHX)
    Fredia Huya-Kouadio (m4gr3d)
    Geequlim
    George Marques (vnen)
    Gerrit Großkopf (Grosskopf)
    Gilles Roudiere (groud)
    Gordon MacPherson (RevoluPowered)
    Guilherme Felipe de C. G. da Silva (guilhermefelipecgs)
    Hanif Bin Ariffin (hbina)
    Haoyu Qiu (timothyqiu)
    Hein-Pieter van Braam-Stewart (hpvb)
    Hiroshi Ogawa (hi-ogawa)
    homer666
    Hubert Jarosz (Marqin)
    Hugo Locurcio (Calinou)
    Ian Bishop (ianb96)
    Ibrahn Sahir (ibrahn)
    Ignacio Etcheverry (neikeq)
    Ilaria Cislaghi (QbieShay)
    Indah Sylvia (ISylvox)
    J08nY
    Jakub Grzesik (kubecz3k)
    James Buck (jbuck3)
    Jérôme Gully (Nutriz)
    Joan Fons Sanchez (JFonS)
    Johan Manuel (29jm)
    Joshua Grams (JoshuaGrams)
    Juan Linietsky (reduz)
    Julian Murgia (StraToN)
    Justo Delgado (mrcdk)
    Kelly Thomas (KellyThomas)
    Kostadin Damyanov (Max-Might)
    K. S. Ernest (iFire) Lee (fire)
    lawnjelly
    Leon Krause (eska014)
    Lucien Menassol (Kanabenki)
    m4nu3lf
    Maganty Rushyendra (mrushyendra)
    Marcel Admiraal (madmiraal)
    Marcelo Fernandez (marcelofg55)
    Marc Gilleron (Zylann)
    Marcin Zawiejski (dragmz)
    Marcus Brummer (mbrlabs)
    Marcus (MCrafterzz)
    Mariano Javier Suligoy (MarianoGnu)
    Mario Schlack (hurikhan)
    Martin Capitanio (capnm)
    Martin Liška (marxin)
    Martin Sjursen (binbitten)
    marynate
    Masoud BH (masoudbh3)
    Mateo Kuruk Miccino (kuruk-mm)
    Matthias Hölzl (hoelzl)
    Max Hilbrunner (mhilbrunner)
    merumelu
    Michael Alexsander (YeldhamDev)
    MichiRecRoom (LikeLakers2)
    mrezai
    muiroc
    Nathan Warden (NathanWarden)
    Nils André-Chang (NilsIrl)
    Nuno Donato (nunodonato)
    Ovnuniarchos
    Pascal Richter (ShyRed)
    Patrick (firefly2442)
    Paul Batty (Paulb23)
    Paul Joannon (paulloz)
    Paul Trojahn (ptrojahn)
    Pawel Kowal (pkowal1982)
    Pedro J. Estébanez (RandomShaper)
    Pieter-Jan Briers (PJB3005)
    Poommetee Ketson (Noshyaar)
    Przemysław Gołąb (n-pigeon)
    Rafał Mikrut (qarmin)
    Ralf Hölzemer (rollenrolm)
    Ramesh Ravone (RameshRavone)
    raphael10241024
    Ray Koopa (RayKoopa)
    Rémi Verschelde (akien-mga)
    Rhody Lugo (rraallvv)
    Roberto F. Arroyo (robfram)
    Robin Hübner (profan)
    romulox-x
    Ruslan Mustakov (endragor)
    Saniko (sanikoyes)
    santouits
    SaracenOne
    sersoong
    Shiqing (kawa-yoiko)
    Simon Wenner (swenner)
    Swarnim Arun (minraws)
    Thakee Nathees (ThakeeNathees)
    Theo Hallenius (TheoXD)
    Thomas Herzog (karroffel)
    Timo Schwarzer (timoschwarzer)
    Timo (toger5)
    Tomasz Chabora (KoBeWi)
    Twarit Waikar (IronicallySerious)
    Vinzenz Feenstra (vinzenz)
    박한얼 (volzhs)
    V. Vamsi Krishna (vkbsb)
    Wilhem Barbier (nounoursheureux)
    Will Nations (willnationsdev)
    Wilson E. Alvarez (Rubonnek)
    Xavier Cho (mysticfall)
    yg2f (SuperUserNameMan)
    Yuri Roubinsky (Chaosus)
    Zak Stam (zaksnet)
    Zher Huei Lee (leezh)
    ZuBsPaCe

==> godot-4.0-beta1.tar.xz: godot-4.0-beta1/AUTHORS.md <==
# Godot Engine authors

Godot Engine is developed by a community of voluntary contributors who
contribute code, bug reports, documentation, artwork, support, etc.

It is impossible to list them all; nevertheless, this file aims at listing
the developers who contributed significant patches to this MIT licensed
source code. "Significant" is arbitrarily decided, but should be fair :)

GitHub usernames are indicated in parentheses, or as sole entry when no other
name is available.

## Project Founders

    Juan Linietsky (reduz)
    Ariel Manzur (punto-)

## Lead Developer

    Juan Linietsky (reduz)

## Project Manager

    Rémi Verschelde (akien-mga)

## Developers

(in alphabetical order, with over 10 commits excluding merges)

    Aaron Franke (aaronfranke)
    Aaron Record (LightningAA)
    Alexander Holland (AlexHolly)
    Alexey Khoroshavin (allkhor)
    Alket Rexhepi (alketii)
    Andrea Catania (AndreaCatania)
    Andrii Doroshenko (Xrayez)
    Andy Moss (MillionOstrich)
    Angad Kambli (angad-k)
    Anilforextra (AnilBK)
    Anish Bhobe (KidRigger)
    Anton Yabchinskiy (a12n)
    Anutrix
    Aren Villanueva (kurikaesu)
    Ariel Manzur (punto-)
    Bartłomiej T. Listwon (Listwon)
    Bastiaan Olij (BastiaanOlij)
    Ben Brookshire (sheepandshepherd)
    Benjamin Larsson (Nallebeorn)
    Bernhard Liebl (poke1024)
    Bhuvan Vemula (Bhu1-V)
    Błażej Szczygieł (zaps166)
    Bojidar Marinov (bojidar-bg)
    Brian Semrau (briansemrau)
    Bruno Lourenço (MadEqua)
    Cameron Reikes (creikey)
    Camille Mohr-Daurat (pouleyKetchoupp)
    Caner Demirer (cdemirer)
    Carl Olsson (not-surt)
    Carter Anderson (cart)
    Chris Bradfield (cbscribe)
    Clay John (clayjohn)
    ConteZero
    Dana Olson (adolson)
    Daniel J. Ramirez (djrm)
    Daniel Rakos (aqnuep)
    Danil Alexeev (dalexeev)
    dankan1890
    David Cambré (Gallilus)
    David Sichma (DavidSichma)
    David Snopek (dsnopek)
    Dharkael (lupoDharkael)
    Dmitry Koteroff (Krakean)
    Dominik Jasiński (dreamsComeTrue)
    DualMatrix
    Ellen Poe (ellenhp)
    Emmanuel Barroga (codecustard)
    Emmanuel Leblond (touilleMan)
    Eoin O'Neill (Eoin-ONeill-Yokai)
    Eric Lasota (elasota)
    Eric M (EricEzaM)
    Eric Rybicki (ericrybick)
    Erik Selecký (rxlecky)
    est31
    Eveline Jarosz (Marqin)
    Fabian Mathews (supagu)
    Fabio Alessandrelli (Faless)
    Fabrice Cipolla (fabriceci)
    Ferenc Arn (tagcup)
    FireForge (fire-forge)
    follower
    foxydevloper
    François Belair (Razoric480)
    Franklin Sobrinho (TheHX)
    Fredia Huya-Kouadio (m4gr3d)
    Geequlim
    George Marques (vnen)
    Gerrit Großkopf (Grosskopf)
    Gilles Roudiere (groud)
    Gordon MacPherson (RevoluPowered)
    Guilherme Felipe de C. G. da Silva (guilhermefelipecgs)
    Hanif Bin Ariffin (hbina)
    Haoyu Qiu (timothyqiu)
    Hein-Pieter van Braam-Stewart (hpvb)
    Hendrik Brucker (Geometror)
    hilfazer
    Hiroshi Ogawa (hi-ogawa)
    homer666
    hoontee
    Hugo Locurcio (Calinou)
    Ian Bishop (ianb96)
    Ibrahn Sahir (ibrahn)
    Ignacio Etcheverry (neikeq)
    Igor Kordiukiewicz (IgorKordiukiewicz)
    Ilaria Cislaghi (QbieShay)
    Indah Sylvia (ISylvox)
    J08nY
    Jake Young (Duroxxigar)
    Jakub Grzesik (kubecz3k)
    James Buck (jbuck3)
    Jean-Michel Bernard (jmb462)
    Jérôme Gully (Nutriz)
    Jia Jun Chai (SkyLucilfer)
    Joan Fons Sanchez (JFonS)
    Johan Manuel (29jm)
    Johannes Witt (HaSa1002)
    Jordan Schidlowsky (winterpixelgames)
    Joshua Grams (JoshuaGrams)
    Juan Linietsky (reduz)
    Julian Murgia (StraToN)
    Julien Nguyen (Blackiris)
    Jummit
    Justo Delgado (mrcdk)
    karroffel
    Kelly Thomas (KellyThomas)
    kleonc
    Kongfa Waroros (gongpha)
    Kostadin Damyanov (Max-Might)
    K. S. Ernest (iFire) Lee (fire)
    lawnjelly
    Leon Krause (leonkrause)
    Liz Haas (27thLiz)
    Lucien Menassol (Kanabenki)
    Lyuma
    Maganty Rushyendra (mrushyendra)
    Manuele Finocchiaro (m4nu3lf)
    Marcel Admiraal (madmiraal)
    Marcelo Fernandez (marcelofg55)
    Marc Gilleron (Zylann)
    Marcin Zawiejski (dragmz)
    Marcus Brummer (mbrlabs)
    Marcus Elg (MCrafterzz)
    Mariano Javier Suligoy (MarianoGnu)
    Mario Schlack (hurikhan)
    Marios Staikopoulos (marstaik)
    Mark Riedesel (klowner)
    Markus Sauermann (Sauermann)
    Martin Capitanio (capnm)
    Martin Liška (marxin)
    Martin Sjursen (binbitten)
    marynate
    Masoud BH (masoudbh3)
    Mateo Kuruk Miccino (kuruk-mm)
    Matthew (skyace65)
    Matthias Hölzl (hoelzl)
    Max Hilbrunner (mhilbrunner)
    merumelu
    Meru Patel (Janglee123)
    Michael Alexsander (YeldhamDev)
    Michał Iwańczuk (iwek7)
    MichiRecRoom (LikeLakers2)
    Morris "Tabor" Arroad (mortarroad)
    mrezai
    Muhammad Huri (CakHuri)
    muiroc
    Nathan Franke (nathanfranke)
    Nathan Lovato (NathanLovato)
    Nathan Warden (NathanWarden)
    Nicholas Huelin (SirQuartz)
    Nils André-Chang (NilsIrl)
    Noah Beard (TwistedTwigleg)
    Nuno Donato (nunodonato)
    Omar El Sheikh (The-O-King)
    Ovnuniarchos
    Pascal Richter (ShyRed)
    Patrick (firefly2442)
    Paul Batty (Paulb23)
    Paul Joannon (paulloz)
    Paul Trojahn (ptrojahn)
    Pāvels Nadtočajevs (bruvzg)
    Paweł Fertyk (pfertyk)
    Pawel Kowal (pkowal1982)
    Pawel Lampe (Scony)
    Pedro J. Estébanez (RandomShaper)
    Pieter-Jan Briers (PJB3005)
    Poommetee Ketson (Noshyaar)
    Przemysław Gołąb (n-pigeon)
    Rafael M. G. (rafallus)
    Rafał Mikrut (qarmin)
    Ralf Hölzemer (rollenrolm)
    Ramesh Ravone (RameshRavone)
    Raphael2048
    Raul Santos (raulsntos)
    Ray Koopa (RayKoopa)
    Rémi Verschelde (akien-mga)
    Rhody Lugo (rraallvv)
    Ricardo Buring (rburing)
    Ricardo Subtil (Ev1lbl0w)
    Roberto F. Arroyo (robfram)
    Robin Hübner (profan)
    romulox-x
    Ruslan Mustakov (endragor)
    Ryan Roden-Corrent (rrcore)
    Saniko (sanikoyes)
    santouits
    SaracenOne
    Sergey Minakov (naithar)
    sersoong
    Shiqing (kawa-yoiko)
    Silc 'Tokage' Renew (TokageItLab)
    Simon Wenner (swenner)
    smix8
    Stijn Hinlopen (hinlopen)
    Swarnim Arun (minraws)
    TC (floppyhammer)
    Thakee Nathees (ThakeeNathees)
    thebestnom
    Theo Hallenius (TheoXD)
    Timo Schwarzer (timoschwarzer)
    Timo (toger5)
    Tomasz Chabora (KoBeWi)
    trollodel
    Twarit Waikar (IronicallySerious)
    Umang Kalra (theoway)
    Vinzenz Feenstra (vinzenz)
    Vitika Soni (Vitika9)
    박한얼 (volzhs)
    V. Vamsi Krishna (vkbsb)
    Wilhem Barbier (nounoursheureux)
    William Deurwaarder (williamd67)
    Will Nations (willnationsdev)
    Wilson E. Alvarez (Rubonnek)
    Xavier Cho (mysticfall)
    yg2f (SuperUserNameMan)
    Yuri Rubinsky (Chaosus)
    Yuri Sizov (YuriSizov)
    Zae Chao (zaevi)
    Zak Stam (zaksnet)
    Zher Huei Lee (leezh)
    ZuBsPaCe
    风青山 (Rindbee)
